# Slixmpp: The Slick XMPP Library
# Copyright (C) 2010  Nathanael C. Fritz
# This file is part of Slixmpp.
# See the file LICENSE for copying permission.
# We don't want to have to import the entire library
# just to get the version info for setup.py

__version__ = '1.8.3'
__version_info__ = (1, 8, 3)
